@@ -12,6 +12,33 @@
 
 
 
+/**
+  * Load configuration file
+  *
+  */
+function hm_get_config()
+{
+
+   // Load sample config file, then allow overrides in
+   // customized version thereof (order is important here!); 
+   // error if neither is found
+   //
+/* Who wants to tell me why this returns TRUE when both files exist?!?
+   if (!@include_once(SM_PATH . 'plugins/html_mail/config.php.sample')
+    && !@include_once(SM_PATH . 'plugins/html_mail/config.php'))
+*/
+   $one = @include_once(SM_PATH . 'plugins/html_mail/config.php.sample');
+   $two = @include_once(SM_PATH . 'plugins/html_mail/config.php');
+   if (!$one && !$two)
+      {
+         echo sprintf(_("ERROR (%s): can't load config file"), 'html_mail');
+         exit(1);
+      }
+
+}
+
+
+
 /** 
   * Inserts controls on the compose page that let the user
   * switch between HTML and text on the fly.
@@ -46,7 +73,9 @@ function html_mail_choose_type_on_the_fly()
       if ($javascript_on && (($browser == 'Explorer' && $browserVersion >= 5.5)
                           || ($browser == 'Gecko' && $browserVersion >= 20030624)))
 
-         echo '<a href="' . $PHP_SELF . '&comp_in_html=1">'. _("Compose in HTML") . '</a>';
+//         echo '<a href="' . $PHP_SELF . (strpos($PHP_SELF, '?') === FALSE ? '?' : '&') . 'comp_in_html=1">'. _("Compose in HTML") . '</a>';
+//         echo '<input type="button" onclick="window.location=\'' . $PHP_SELF . (strpos($PHP_SELF, '?') === FALSE ? '?' : '&') . 'comp_in_html=1\'" value="'. _("HTML") . '" />';
+         echo '<input type="button" onclick="window.location=\'' . $PHP_SELF . (strpos($PHP_SELF, '?') === FALSE ? '?' : '&') . 'comp_in_html=1\'" value="'. _("Compose in HTML") . '" />';
    }
 
 
@@ -120,7 +149,7 @@ function html_mail_turn_on_htmlarea()
    }
 
 
-   include_once (SM_PATH . 'plugins/html_mail/config.php');
+   hm_get_config();
 
 
    // turn it on if supported/turned on
@@ -290,7 +319,7 @@ function html_mail_footer()
 
    global $editor_style, $html_editor_style, 
           $allow_change_html_editor_style, $username, $data_dir;
-   include_once (SM_PATH . 'plugins/html_mail/config.php');
+   hm_get_config();
 
 
    // insert javascript that actually replaces the text area, but only if supported/turned on
@@ -304,6 +333,8 @@ function html_mail_footer()
       // and miss automated signatures)
       //
       echo '<script language="javascript" type="text/javascript">' . "\n<!--\n"
+         . 'document.compose.body.value = document.compose.body.value.replace(/<br *\/?>(\r\n|\r|\n)/g, "\n");' . "\n"
+         . 'document.compose.body.value = document.compose.body.value.replace(/<\/p>(\r\n|\r|\n)/g, "</p>");' . "\n"
          . 'document.compose.body.value = document.compose.body.value.replace(/\n/g, "<br />");'
          . "\n// -->\n</script>";
 
@@ -317,7 +348,8 @@ function html_mail_footer()
       if ($editor_style == 1)
       {
 
-         global $squirrelmail_language, $editor_height, $editor_size;
+         global $squirrelmail_language, $editor_height, $editor_size, $default_html_editor_height;
+         if (!$editor_height) $editor_height = $default_html_editor_height;
          $fckeditor_language = substr($squirrelmail_language, 0, strpos($squirrelmail_language, '_'));
          if (!file_exists(SM_PATH . 'plugins/html_mail/fckeditor/editor/lang/' . $fckeditor_language . '.js'))
             $fckeditor_language = 'en';
@@ -417,7 +449,7 @@ function html_mail_emoticons_do()
    global $username, $data_dir, $allowEmoticons, $use_emoticons, $editor_style,
           $html_editor_style, $allow_change_html_editor_style, $username, $data_dir;
 
-   include_once (SM_PATH . 'plugins/html_mail/config.php');
+   hm_get_config();
 
 
    if ($allow_change_html_editor_style)
@@ -903,7 +935,7 @@ function html_mail_display($hookName)
           $allow_change_html_editor_style, $html_mail_aggressive_reply_with_unsafe_images,
           $default_aggressive_reply_with_unsafe_images;
 
-   include_once (SM_PATH . 'plugins/html_mail/config.php');
+   hm_get_config();
 
    $email_type = getPref($data_dir, $username, 'compose_window_type', '');
    $html_mail_aggressive_reply = getPref($data_dir, $username, 'html_mail_aggressive_reply', $default_aggressive_html_reply);
@@ -1044,7 +1076,7 @@ function html_mail_save($hookName)
           $html_mail_aggressive_reply, $html_mail_aggressive_reply_with_unsafe_images,
           $allow_change_html_editor_style;
 
-   include_once (SM_PATH . 'plugins/html_mail/config.php');
+   hm_get_config();
 
 
    sqgetGlobalVar('email_type', $email_type, SQ_FORM);
@@ -1134,7 +1166,7 @@ function html_mail_alter_type_do(&$argv)
          // figure out how images should be linked (HTTP/HTTPS)
          //
          global $outgoing_image_uri_https;
-         include_once (SM_PATH . 'plugins/html_mail/config.php');
+         hm_get_config();
          if ($outgoing_image_uri_https == 1)
             $http = 'http';
          else if ($outgoing_image_uri_https == 2)
@@ -1178,15 +1210,13 @@ function html_mail_alter_type_do(&$argv)
             $message->entities[0]->mime_header->type1 = 'html';
             $htmlTextPart = $message->entities[0];
 
-            $plainTextPart = new Message();
-            $plainTextPart->body_part = $plainText;
-            $mime_header = new MessageHeader;
-            $mime_header->type0 = 'text';
-            $mime_header->type1 = 'plain';
-            $mime_header->encoding = $message->entities[0]->mime_header->encoding;
-            $mime_header->parameters = $message->entities[0]->mime_header->parameters;
-            $plainTextPart->mime_header = $mime_header;
+            // break connection between $htmlTextPart and $message
+            unset($message->entities[0]);
+            // create new message part in place of removed one
+            $message->entities[0] = new Message();
+            $message->entities[0]->mime_header = new MessageHeader();
 
+            // tag that message part as multipart alternative
             $message->entities[0]->mime_header->type0 = 'multipart';
             $message->entities[0]->mime_header->type1 = 'alternative';
             $message->entities[0]->mime_header->encoding = '';
@@ -1196,8 +1226,20 @@ function html_mail_alter_type_do(&$argv)
             // gets us a different message boundary 
             $message->entities[0]->entity_id = 'usf' . mt_rand(1000, 9999);
 
+            // create new plaintext message
+            $plainTextPart = new Message();
+            $plainTextPart->body_part = $plainText;
+            $mime_header = new MessageHeader;
+            $mime_header->type0 = 'text';
+            $mime_header->type1 = 'plain';
+            $mime_header->encoding = $message->entities[0]->mime_header->encoding;
+            $mime_header->parameters = $message->entities[0]->mime_header->parameters;
+            $plainTextPart->mime_header = $mime_header;
+
+            // add plain text and html entities to multipart/alternative message
+            $message->entities[0]->addEntity($plainTextPart);
+            $message->entities[0]->addEntity($htmlTextPart);
 
-            $message->entities[0]->entities = array($plainTextPart, $htmlTextPart);
 //echo "<hr>";sm_print_r($message);echo "<hr>";exit;
          }
 
